/*
 *	Incremental search
 *	Copyright
 *		(C) 1992 Joseph H. Allen
 *
 *	This file is part of JOE (Joe's Own Editor)
 */
#ifndef JUPP_UISRCH_H
#define JUPP_UISRCH_H

#ifdef EXTERN_CMD_C
__IDSTRING(rcsid_uisrch_h, "$MirOS: contrib/code/jupp/uisrch.h,v 1.6 2020/03/27 06:38:59 tg Exp $");
#endif

int uisrch(BW *bw);
int ursrch(BW *bw);

#endif
